@@ -14,7 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
-from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.client import ClientMeta
 
 from mypy_boto3_ce.type_defs import (
     CostCategoryRuleTypeDef,
@@ -52,28 +52,37 @@ else:
 __all__ = ("CostExplorerClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    BillExpirationException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    DataUnavailableException: Type[Boto3ClientError]
-    InvalidNextTokenException: Type[Boto3ClientError]
-    LimitExceededException: Type[Boto3ClientError]
-    RequestChangedException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
-    ServiceQuotaExceededException: Type[Boto3ClientError]
-    UnresolvableUsageUnitException: Type[Boto3ClientError]
+    BillExpirationException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    DataUnavailableException: Type[BotocoreClientError]
+    InvalidNextTokenException: Type[BotocoreClientError]
+    LimitExceededException: Type[BotocoreClientError]
+    RequestChangedException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
+    ServiceQuotaExceededException: Type[BotocoreClientError]
+    UnresolvableUsageUnitException: Type[BotocoreClientError]
 
 
 class CostExplorerClient:
     """
-    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client)
+    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.can_paginate)
         """
 
     def create_cost_category_definition(
@@ -83,21 +92,21 @@ class CostExplorerClient:
         Rules: List["CostCategoryRuleTypeDef"],
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         """
 
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         """
 
     def generate_presigned_url(
@@ -108,7 +117,7 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         """
 
     def get_cost_and_usage(
@@ -121,7 +130,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         """
 
     def get_cost_and_usage_with_resources(
@@ -134,7 +143,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         """
 
     def get_cost_forecast(
@@ -154,7 +163,7 @@ class CostExplorerClient:
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         """
 
     def get_dimension_values(
@@ -196,7 +205,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         """
 
     def get_reservation_coverage(
@@ -209,7 +218,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         """
 
     def get_reservation_purchase_recommendation(
@@ -232,7 +241,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         """
 
     def get_reservation_utilization(
@@ -244,7 +253,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         """
 
     def get_rightsizing_recommendation(
@@ -256,7 +265,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         """
 
     def get_savings_plans_coverage(
@@ -270,7 +279,7 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         """
 
     def get_savings_plans_purchase_recommendation(
@@ -292,7 +301,7 @@ class CostExplorerClient:
         Filter: Dict[str, Any] = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         """
 
     def get_savings_plans_utilization(
@@ -302,7 +311,7 @@ class CostExplorerClient:
         Filter: Dict[str, Any] = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         """
 
     def get_savings_plans_utilization_details(
@@ -313,7 +322,7 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         """
 
     def get_tags(
@@ -324,7 +333,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_tags)
         """
 
     def get_usage_forecast(
@@ -344,14 +353,14 @@ class CostExplorerClient:
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         """
 
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         """
 
     def update_cost_category_definition(
@@ -361,5 +370,5 @@ class CostExplorerClient:
         Rules: List["CostCategoryRuleTypeDef"],
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.59/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         """
